couchdb

Package couchdb |

# Package couchdb

Version: 0.6

Submodules
couchdb.client: Python client API for CouchDB. couchdb.design: Utility code for managing design documents. couchdb.json: Thin abstraction layer over the different available modules for decoding and encoding JSON data. couchdb.multipart: Support for streamed reading and writing of multipart MIME content. couchdb.schema: Mapping from raw JSON data structures to Python objects and vice versa. couchdb.tools couchdb.tools.dump: Utility for dumping a snapshot of a CouchDB database to a multipart MIME file. couchdb.tools.load: Utility for loading a snapshot of a CouchDB database from a multipart MIME file. couchdb.tools.replication_helper: CouchDB `update_notification` script that triggers replication. couchdb.tools.replication_helper_test: Simple functional test for the replication notification trigger couchdb.view: Implementation of a view server for functions written in Python.

Variables
| __package__ = ``'``couchdb``'``